<?php
/**
 * $Horde: whups/ticket/queue.php,v 1.11 2005/01/03 14:35:46 jan Exp $
 *
 * Copyright 2001-2005 Robert E. Coyle <robertecoyle@hotmail.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
 */

@define('WHUPS_BASE', dirname(__FILE__) . '/..');
require_once WHUPS_BASE . '/lib/base.php';
require_once WHUPS_BASE . '/lib/Ticket.php';
require_once 'Horde/Variables.php';

if (!Auth::isAdmin('whups:admin')) {
    $notification->push(_("Permission Denied"), 'horde.error');
    header('Location: ' . Horde::applicationUrl($prefs->getValue('whups_default_view') . '.php', true));
    exit;
}

/**
 * Queue editing forms.
 */
class SetQueueStep1Form extends Horde_Form {

    function SetQueueStep1Form(&$vars, $title = '')
    {
        global $whups;

        parent::Horde_Form($vars, $title);

        $this->addHidden('', 'id', 'int', true, true);

        /* Queues. */
        $queue = $vars->get('queue');
        $this->addVariable(_("New Queue"), 'queue', 'enum', true, false, null, array($whups->getQueues()));
        $this->addVariable(_("Comment"), 'newcomment', 'longtext', false);

        /* Group restrictions. */
        if (Auth::isAdmin('whups:admin') ||
            $GLOBALS['perms']->hasPermission('whups:hiddenComments', Auth::getAuth(), PERMS_EDIT)) {
            $groups = &Group::singleton();
            $mygroups = $groups->getGroupMemberships(Auth::getAuth());
            if (count($mygroups)) {
                $grouplist = array(0 => _("Any Group"));
                foreach ($mygroups as $group) {
                    $grouplist[$group] = $group;
                }
                $this->addVariable(_("Viewable only by members of"), 'group', 'enum', true, false, null, array($grouplist));
            }
        }
    }

}

class SetQueueStep2Form extends Horde_Form {

    function SetQueueStep2Form(&$vars, $title = '')
    {
        global $whups;

        parent::Horde_Form($vars, $title);

        $this->addHidden('', 'id', 'int', true, true);
        $this->addHidden('', 'group', 'int', true, true);
        $this->addHidden('', 'queue', 'int', true, true);
        $this->addHidden('', 'newcomment', 'longtext', false, true);

        /* Give the user an opportunity to check that type, version,
         * etc. are still valid. */
        $queue = $vars->get('queue');

        $info = $whups->getQueue($queue);
        if (!empty($info['versioned'])) {
            $versions = $whups->getVersions($vars->get('queue'));
            if (count($versions) == 0) {
                $vtype = 'invalid';
                $v_params = array(_("This queue requires that you specify a version, but there are no versions associated with it. Until versions are created for this queue, you will not be able to create tickets."));
            } else {
                $vtype = 'enum';
                $v_params = array($versions);
            }
            $this->addVariable(_("Queue Version"), 'version', $vtype, true, false, null, $v_params);
        }

        $this->addVariable(_("Type"), 'type', 'enum', true, false, null, array($whups->getTypes($queue)));
    }

}

class SetQueueStep3Form extends Horde_Form {

    function SetQueueStep3Form(&$vars, $title = '')
    {
        global $whups;

        parent::Horde_Form($vars, $title);

        $this->addHidden('', 'id', 'int', true, true);
        $this->addHidden('', 'group', 'int', true, true);
        $this->addHidden('', 'queue', 'int', true, true);
        $this->addHidden('', 'type', 'int', true, true);
        $this->addHidden('', 'version', 'int', true, true);
        $this->addHidden('', 'newcomment', 'longtext', false, true);

        /* Give user an opportunity to check that state and priority
         * are still valid. */
        $type = $vars->get('type');
        $this->addVariable(_("State"), 'state', 'enum', true, false, null, array($whups->getStates($type)));
        $this->addVariable(_("Priority"), 'priority', 'enum', true, false, null, array($whups->getPriorities($type)));
    }

}

$ticket = &Whups::getCurrentTicket();
$vars = &Variables::getDefaultVariables();
$vars->set('id', $id = $ticket->getId());
foreach ($ticket->getDetails() as $varname => $value) {
    $vars->add($varname, $value);
}

$form = $vars->get('formname');
$action = '';

if ($form == 'setqueuestep1form') {
    $setqueueform = &new SetQueueStep1Form($vars);

    if ($setqueueform->isValid()) {
        $action = 'sq2';
    }
}

if ($form == 'setqueuestep2form') {
    $setqueueform = &new SetQueueStep2Form($vars);

    if ($setqueueform->isValid()) {
        $action = 'sq3';
    } else {
        $action = 'sq2';
    }
}

if ($form == 'setqueuestep3form') {
    $smform3 = &new SetQueueStep3Form($vars);

    if ($smform3->isValid($vars)) {
        $smform3->getInfo($vars, $info);

        $ticket->change('queue', $info['queue']);
        $ticket->change('type', $info['type']);
        $ticket->change('state', $info['state']);
        $ticket->change('priority', $info['priority']);

        if (!empty($info['version'])) {
            $ticket->change('version', $info['version']);
        }

        if (!empty($info['newcomment'])) {
            $ticket->change('comment', $info['newcomment']);
        }

        if (!empty($info['group'])) {
            $ticket->change('comment-perms', $info['group']);
        }

        $result = $ticket->commit();
        if (is_a($result, 'PEAR_Error')) {
            $notification->push($result, 'horde.error');
        } else {
            $notification->push(sprintf(_("Moved ticket %d to '%s'"), $id, $ticket->get('queue_name')), 'horde.success');
            $ticket->show();
        }
    } else {
        $action = 'sq3';
    }
}

$title = sprintf(_("Set Queue for %s"), '[#' . $id . '] ' . $ticket->get('summary'));
require WHUPS_TEMPLATES . '/common-header.inc';
require WHUPS_TEMPLATES . '/menu.inc';
require WHUPS_TEMPLATES . '/prevnext.inc';

$tabs = &Whups::getTicketTabs($vars);
$tabs->preserve('id', $id);
echo $tabs->render();

$r = &new Horde_Form_Renderer();

switch ($action) {
case 'sq2':
    $form1 = &new SetQueueStep1Form($vars, _("Set Queue - Step 1"));
    $form2 = &new SetQueueStep2Form($vars, _("Set Queue - Step 2"));

    $form1->renderInactive($r, $vars);
    echo '<br />';
    $form2->renderActive($r, $vars, 'queue.php', 'post');
    break;

case 'sq3':
    $form1 = &new SetQueueStep1Form($vars, _("Set Queue - Step 1"));
    $form2 = &new SetQueueStep2Form($vars, _("Set Queue - Step 2"));
    $form3 = &new SetQueueStep3Form($vars, _("Set Queue - Step 3"));

    $form1->renderInactive($r, $vars);
    echo '<br />';
    $form2->renderInactive($r, $vars);
    echo '<br />';
    $form3->renderActive($r, $vars, 'queue.php', 'post');
    break;

default:
    $form1 = &new SetQueueStep1Form($vars, _("Set Queue - Step 1"));
    $form1->renderActive($r, $vars, 'queue.php', 'post');
    break;
}

require $registry->get('templates', 'horde') . '/common-footer.inc';
